# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2017-07-06 13:13:34.217908
from __future__ import unicode_literals
import datetime

version = "2.0"
githash = "ed2e7897862ae9e979b336df670d7a5541cdd8f0"


major = 2
minor = 0
bugfix = 0

release = True
timestamp = datetime.datetime(2017, 7, 6, 13, 13, 34, 217908)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
